/*
 *  Module Name:     aipdebug.h
 *
 *  Description:     kernel driver debug support
 *
 *  (C) Copyright 2008,2009, International Business Machines Corporation.
 *  All right reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1.  Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *
 * 2.  Redistributions in binary form must reproduce the above copyright notice,
 *     this list of conditions and the following disclaimer in the documentation
 *     and/or other materials provided with the distribution.
 *
 * 3.  The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * Should you need to contact me, the author, you can do so either by
 * e-mail - mail your message to <gha@us.ibm.com>.
 */

#ifndef _H_AIPDEBUG
#define _H_AIPDEBUG 1

static int debug = 0;
static int verbose = 0;

#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 0)

MODULE_PARM(debug, "i");

#else

module_param(debug, bool, S_IRUGO | S_IWUSR);
MODULE_PARM_DESC(debug, "true to log all debug statements");

module_param(verbose, bool, S_IRUGO | S_IWUSR);
MODULE_PARM_DESC(verbose, "true to log all verbose statements");

#endif


#define aip_warning(fmt, args...)				\
	do {							\
	    printk(KERN_WARNING "%s(%s): " fmt , DEVDRVR_ID , __FUNCTION__ , ## args); \
	} while (0)

#define aip_error(fmt, args...)				\
	do {							\
	    printk(KERN_ERR "%s(%s): " fmt , DEVDRVR_ID , __FUNCTION__ , ## args); \
	} while (0)

#define aip_info(fmt, args...)				\
	do {							\
	    printk(KERN_INFO "%s: " fmt , DEVDRVR_ID , ## args); \
	} while (0)

#define aip_dbg(fmt, args...)				\
	do {						\
		if (debug)				\
		    printk(KERN_INFO "%s(%s): " fmt , DEVDRVR_ID , __FUNCTION__ , ## args); \
	} while (0)

#define aip_verbose(fmt, args...)				\
	do {						\
		if (verbose && debug)				\
		    printk(KERN_INFO "%s(%s): " fmt , DEVDRVR_ID , __FUNCTION__ , ## args); \
	} while (0)

#endif
